@@ -16,7 +16,7 @@
 
 #include "keduvocpaukerreader.h"
 
-#include <klocalizedstring.h>
+#include <KLocalizedString>
 #include <QIODevice>
 #include <QTextStream>
 
